# Stewie
Simple Terminal Widget Engine

Stewie is going to be yet another python3 module that provides
widgets for simple terminal user interfaces.
This project is merely a prototype and it should not
be used for serious software projects in its current state.

## Installation
TBD

## Usage
TBD

## Documentation
TBD